@@ -77,8 +77,8 @@ class CVPCON():
             'getConfigletBuilder': 'cvpservice/configlet/getConfigletBuilder.do',
             'searchTopo': 'cvpservice/provisioning/searchTopology.do',
             'getContainer': 'cvpservice/inventory/containers',
-            'getContainerInfo': '/cvpservice/provisioning/getContainerInfoById.do',
-            'getConfigletsByNetElementId': '/cvpservice/provisioning/getConfigletsByNetElementId.do',
+            'getContainerInfo': 'cvpservice/provisioning/getContainerInfoById.do',
+            'getConfigletsByNetElementId': 'cvpservice/provisioning/getConfigletsByNetElementId.do',
             'addTempAction': 'cvpservice/provisioning/addTempAction.do',
             'deviceInventory': 'cvpservice/inventory/devices',
             'deleteDevice': 'cvpservice/inventory/deleteDevices.do',
@@ -94,7 +94,10 @@ class CVPCON():
             'generateCB': 'cvpservice/configlet/autoConfigletGenerator.do',
             'getTempConfigs': 'cvpservice/provisioning/getTempConfigsByNetElementId.do',
             'createSnapshot': 'cvpservice/snapshot/templates/schedule',
-            'getAllSnapshots': 'cvpservice/snapshot/templates'
+            'getAllSnapshots': 'cvpservice/snapshot/templates',
+            'getCertificate': 'cvpservice/ssl/getCertificate.do',
+            'generateCertificate': 'cvpservice/ssl/generateCertificate.do',
+            'installCertificate': 'cvpservice/ssl/installCertificate.do'
         }
 
         self.headers = {
@@ -143,8 +146,8 @@ class CVPCON():
         """
         Function that saves all Temporary Provisioning Actions/Tasks
         """
-        payload = self._sendRequest("GET",self.cvp_api['getAllTemp'])['data']
-        response = self._sendRequest("POST",self.cvp_api['saveTopo'],payload)
+        # payload = self._sendRequest("GET",self.cvp_api['getAllTemp'])['data']
+        response = self._sendRequest("POST",self.cvp_api['saveTopo'],[])
         return(response)
         
     def getSID(self):
@@ -380,17 +383,17 @@ class CVPCON():
         if 'key' in cCheck.keys():
             if cCheck['type'] == 'Builder':
                 response = self.updateConfigletBuilder(cName,cScript,cCheck['key'],cFormList)
-                return(response)
+                return(("Updated",response))
             elif cCheck['type'] == 'Static':
                 response = self.updateConfiglet(cName,cScript,cCheck['key'])
-                return(response)
+                return(("Updated",response))
         else:
             if cType.lower() == 'static':
                 response = self.addConfiglet(cName,cScript)
-                return(response)
+                return(("Added",response))
             elif cType.lower() == 'builder':
                 response = self.addConfigletBuilder(cName,cScript,cFormList)
-                return(response)
+                return(("Added",response))
 
     def addConfiglet(self,conName,conData):
         """
@@ -696,4 +699,54 @@ class CVPCON():
         Function to get all configured snapshots on CVP
         """
         response = self._sendRequest("GET",self.cvp_api['getAllSnapshots'] + "?startIndex=0&endIndex=0")
-        self.snapshots = response['templateKeys']
\ No newline at end of file
+        self.snapshots = response['templateKeys']
+    
+    # ================================
+    # SSL Certificates Section
+    # ================================
+
+    def getCerts(self,certType='cvpCert'):
+        """
+        Function to get installed certs in CVP.
+        Parameters:
+        certType = Type of cert (optional) 
+            Options:
+                - cvpCert (default) self-signed
+                - csr
+                - dcaCert
+        """
+        response = self._sendRequest("GET",self.cvp_api['getCertificate'] + "?certType={}".format(certType))
+        return(response)
+
+    def generateCert(self, cName, organization, organizationUnit, description, validity):
+        """
+        Function to generate a self-signed cert.
+        Parameters:
+        cName = Common Name (required)
+        organization = Organization (requried)
+        organizationUnit = Organizational Unit (required)
+        description = Description (required)
+        validity = Valid lengh in days (required) int
+        """
+        payload = {
+            "certType": "cvpCert",
+            "commonName": cName,
+            "organization": organization,
+            "organizationUnit": organizationUnit,
+            "description": description,
+            "keyLength": 2048,
+            "digestAlgorithm": "SHA256withRSA",
+            "encryptAlgorithm": "RSA",
+            "validity": validity
+        }
+        response = self._sendRequest("POST",self.cvp_api['generateCertificate'], payload)
+        return(response)
+    
+    def installCert(self):
+        """
+        Function to install proposed Certs.
+        Parameters:
+        None
+        """
+        response = self._sendRequest("POST",self.cvp_api['installCertificate'])
+        return(response)
